# TODO:
# - Subpackages for yum and apt plugins
# - Subpackages for backends (darcs, git, hg)
Summary:	Store /etc in a SCM system (git, mercurial, bzr or darcs)
Name:		etckeeper
Version:	1.18.16
Release:	1
License:	GPL v2+
Group:		Applications/System
Source0:	https://git.joeyh.name/index.cgi/etckeeper.git/snapshot/%{name}-%{version}.tar.gz
# Source0-md5:	3d1636d5b792a8e07d138060fd95cb02
Source1:	pre-install.sh
Source2:	post-install.sh
Source3:	https://ftp.debian.org/debian/pool/main/e/etckeeper/etckeeper_1.18.16-1.debian.tar.xz
# Source3-md5:	49849b13951d76dcb3c4015090a26511
Patch1:		use-libdir.patch
Patch2:		update-ignore.patch
URL:		http://etckeeper.branchable.com/
BuildRequires:	bzr
BuildRequires:	python-devel
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.717
BuildRequires:	sed >= 4.0
Requires:	diffutils
Requires:	findutils
Requires:	mktemp
Requires:	perl-base
Requires:	poldek >= 0.30.1-7.1
Requires:	sed >= 4.0
Suggests:	%{name}-bzr
Suggests:	bash-completion-%{name}
Suggests:	git-core >= 1.6.1-1
Obsoletes:	yum-etckeeper
%if "%{pld_release}" != "ac"
BuildArch:	noarch
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_poldekconfdir	/etc/poldek
%if "%{pld_release}" != "ac"
%define		_poldeklibdir	%{_prefix}/lib/poldek
%else
%define		_poldeklibdir	%{_libdir}/poldek
%endif

%description
The etckeeper program is a tool to let /etc be stored in a git,
mercurial, bzr or darcs repository. It hooks into APT to automatically
commit changes made to /etc during package upgrades. It tracks file
metadata that version control systems do not normally support, but
that is important for /etc, such as the permissions of /etc/shadow.
It's quite modular and configurable, while also being simple to use if
you understand the basics of working with version control.

The default backend is git, if want to use a another backend please
install the appropriate tool (mercurial, darcs or bzr). To use bzr as
backend, please also install the %{name}-bzr package.

To start using the package please read
%{_docdir}/%{name}-%{version}/README

%package bzr
Summary:	Support for bzr with etckeeper
Group:		Applications/System
Requires:	%{name} = %{version}-%{release}
Requires:	bzr

%description bzr
This package provides a bzr backend for etckeeper, if you want to use
etckeeper with bzr backend, install this package.

%package -n bash-completion-%{name}
Summary:	Bash completion routines for %{name}
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	bash-completion
Obsoletes:	etckeeper-bash-completions

%description -n bash-completion-%{name}
Bash completion routines for etckeeper.

%prep
%setup -q -a3
%patch1 -p1
%patch2 -p1

patch -p1 < debian/patches/0002-Default-to-UTF8-encoding-for-consistent-ordering.patch || exit 1

%{__sed} -i -e '
	s|HIGHLEVEL_PACKAGE_MANAGER=apt|HIGHLEVEL_PACKAGE_MANAGER=poldek|;
	s|LOWLEVEL_PACKAGE_MANAGER=dpkg|LOWLEVEL_PACKAGE_MANAGER=rpm|;
' %{name}.conf

# cleanup backups after patching
find '(' -name '*~' -o -name '*.orig' ')' -print0 | xargs -0 -r -l512 rm -f

%build
%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/etc/cron.daily,%{_sysconfdir}/%{name},%{_localstatedir}/cache/%{name}} \
	$RPM_BUILD_ROOT%{_poldekconfdir}/{pre,post}-install.d

%{__make} install \
	etcdir=/lib \
	LOWLEVEL_PACKAGE_MANAGER=rpm \
	HIGHLEVEL_PACKAGE_MANAGER=poldek \
	PYTHON_INSTALL_OPTS="%py_install_opts" \
	INSTALL="install -p" \
	DESTDIR=$RPM_BUILD_ROOT

mv $RPM_BUILD_ROOT{/lib,%{_sysconfdir}}/%{name}/%{name}.conf

install -p debian/cron.daily $RPM_BUILD_ROOT/etc/cron.daily/%{name}
install -p %{SOURCE1} $RPM_BUILD_ROOT%{_poldekconfdir}/pre-install.d/%{name}
install -p %{SOURCE2} $RPM_BUILD_ROOT%{_poldekconfdir}/post-install.d/%{name}

%py_ocomp $RPM_BUILD_ROOT%{py_sitescriptdir}
%py_comp $RPM_BUILD_ROOT%{py_sitescriptdir}
%py_postclean

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ $1 -gt 1 ]; then
	%{_bindir}/%{name} update-ignore
fi

%triggerpostun -- %{name} < 1.18-2
# don't do anything on --downgrade
[ $1 -le 1 ] && exit 0
# poldek itself may be removed
test -f /etc/poldek/poldek.conf || exit 0
# remove our hook as "pm command", poldek supports hooks dir now
# NOTE: poldek own trigger migrating to hooks dir is invoked after this trigger
%{__sed} -i -re 's,^pm command = %{_poldeklibdir}/%{name}.sh,#&,' /etc/poldek/poldek.conf

%files
%defattr(644,root,root,755)
%doc doc/README.mdwn doc/install.mdwn
%dir %{_sysconfdir}/%{name}
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/%{name}/%{name}.conf
%dir /lib/%{name}
%dir /lib/%{name}/*.d
%attr(755,root,root) /lib/%{name}/daily
%attr(755,root,root) /lib/%{name}/*.d/[0-9]*
/lib/%{name}/*.d/README
%attr(755,root,root) /etc/cron.daily/%{name}
%attr(755,root,root) %{_bindir}/%{name}
%{_mandir}/man8/%{name}.8*
%attr(755,root,root) %{_poldekconfdir}/pre-install.d/%{name}
%attr(755,root,root) %{_poldekconfdir}/post-install.d/%{name}
%dir %attr(750,root,root) %{_localstatedir}/cache/%{name}

%{systemdunitdir}/etckeeper.service
%{systemdunitdir}/etckeeper.timer

# subpackages
%exclude /lib/etckeeper/commit.d/30bzr-add

%files bzr
%defattr(644,root,root,755)
/lib/etckeeper/commit.d/30bzr-add
%dir %{py_sitescriptdir}/bzrlib
%dir %{py_sitescriptdir}/bzrlib/plugins
%dir %{py_sitescriptdir}/bzrlib/plugins/%{name}
%{py_sitescriptdir}/bzrlib/plugins/%{name}/*.py[co]
%if "%{pld_release}" != "ac"
%{py_sitescriptdir}/bzr_etckeeper-*.egg-info
%endif

%files -n bash-completion-%{name}
%defattr(644,root,root,755)
%{bash_compdir}/etckeeper
%changelog
* Mon May 31 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/etckeeper.git;a=log;h=master

* Mon May 31 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> 4dda495
- Up to 1.18.16. cron.daily is maintained in debian package only now (take it from here). Fix running daily job (wasn't run at all).

* Fri Feb 21 2020 Arkadiusz Miśkiewicz <arekm@maven.pl> 780b8e7
- up to 1.18.14

* Wed Jan 22 2020 Arkadiusz Miśkiewicz <arekm@maven.pl> 0c2f185
- up to 1.18.13; TODO: package zsh completions

* Mon Dec 02 2019 Jan Rękorajski <baggins@pld-linux.org> 1532e2b
- up to 1.18.12

* Fri Nov 29 2019 Arkadiusz Miśkiewicz <arekm@maven.pl> 6fce163
- up to 1.18.11

* Fri Feb 08 2019 Elan Ruusamäe <glen@pld-linux.org> beb815e
- up to 1.18.10

* Thu Dec 13 2018 Adam Gołębiowski <adamg@pld-linux.org> 13238d8
- updated to 1.18.9

* Wed Aug 22 2018 Elan Ruusamäe <glen@pld-linux.org> 620379e
- up to 1.18.8

* Sat Oct 01 2016 Elan Ruusamäe <glen@delfi.ee> c9313d9
- motd: be smarter and accept ~/.gitconfig from user's homes

* Tue Nov 30 2010 Elan Ruusamäe <glen@delfi.ee> a0b7345
- add script to be printed on system logins

* Sun Jul 31 2016 Tomasz Pala <gotar@pld-linux.org> b149b6f
- upgraded to 1.18.5

* Sun Jul 31 2016 Tomasz Pala <gotar@pld-linux.org> 2c5c397
- CA certificates might be locally modified/updated as well

* Sun Jul 31 2016 Tomasz Pala <gotar@pld-linux.org> 4d0926b
- do not ignore de facto system configuration which is frequently adjusted
for a local system by administrator, as there's no alternate place for overrides

* Sun Jul 31 2016 Tomasz Pala <gotar@pld-linux.org> 83b3097
- do not ignore crucial system configuration data - this made etckeeper
pointless, nobody excludes private data from backups; need for securing
VCS repo is obvious and mentioned in every documentation out there

* Mon Jul 11 2016 Elan Ruusamäe <glen@delfi.ee> 997cc9c
- ignore "udev/hwdb*"

* Wed Jun 29 2016 Elan Ruusamäe <glen@delfi.ee> a5c8826
- package daily script

* Wed Jun 29 2016 Elan Ruusamäe <glen@delfi.ee> 386fe17
- requires diff

* Wed Jun 29 2016 Elan Ruusamäe <glen@delfi.ee> 4a871bb
- package systemd timer (disabled)

* Wed Jun 29 2016 Elan Ruusamäe <glen@delfi.ee> 92ca4cb
- fix python instal (bzr modules)

* Wed Jun 29 2016 Elan Ruusamäe <glen@delfi.ee> 8bc258a
- update bash-completion install

